#[non_exhaustive]pub enum Event<'a> {
Activate {
id: &'a ZwpInputMethodContextV1,
},
Deactivate {
context: &'a ZwpInputMethodContextV1,
},
}Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Activate
activate event
A text input was activated. Creates an input method context object which allows communication with the text input.
Fields

id: &'a ZwpInputMethodContextV1Deactivate
deactivate event
The text input corresponding to the context argument was deactivated. The input method context should be destroyed after deactivation is handled.
Fields

context: &'a ZwpInputMethodContextV1Implementations